@@ -91,6 +91,7 @@ Usage::
         DescribeTransitGatewayRouteTablesPaginator,
         DescribeTransitGatewayVpcAttachmentsPaginator,
         DescribeTransitGatewaysPaginator,
+        DescribeTrunkInterfaceAssociationsPaginator,
         DescribeVolumeStatusPaginator,
         DescribeVolumesModificationsPaginator,
         DescribeVolumesPaginator,
@@ -266,6 +267,7 @@ Usage::
     describe_transit_gateway_route_tables_paginator: DescribeTransitGatewayRouteTablesPaginator = client.get_paginator("describe_transit_gateway_route_tables")
     describe_transit_gateway_vpc_attachments_paginator: DescribeTransitGatewayVpcAttachmentsPaginator = client.get_paginator("describe_transit_gateway_vpc_attachments")
     describe_transit_gateways_paginator: DescribeTransitGatewaysPaginator = client.get_paginator("describe_transit_gateways")
+    describe_trunk_interface_associations_paginator: DescribeTrunkInterfaceAssociationsPaginator = client.get_paginator("describe_trunk_interface_associations")
     describe_volume_status_paginator: DescribeVolumeStatusPaginator = client.get_paginator("describe_volume_status")
     describe_volumes_paginator: DescribeVolumesPaginator = client.get_paginator("describe_volumes")
     describe_volumes_modifications_paginator: DescribeVolumesModificationsPaginator = client.get_paginator("describe_volumes_modifications")
@@ -372,6 +374,7 @@ from .paginator import (
     DescribeTransitGatewayRouteTablesPaginator,
     DescribeTransitGatewaysPaginator,
     DescribeTransitGatewayVpcAttachmentsPaginator,
+    DescribeTrunkInterfaceAssociationsPaginator,
     DescribeVolumesModificationsPaginator,
     DescribeVolumesPaginator,
     DescribeVolumeStatusPaginator,
@@ -524,6 +527,7 @@ __all__ = (
     "DescribeTransitGatewayRouteTablesPaginator",
     "DescribeTransitGatewayVpcAttachmentsPaginator",
     "DescribeTransitGatewaysPaginator",
+    "DescribeTrunkInterfaceAssociationsPaginator",
     "DescribeVolumeStatusPaginator",
     "DescribeVolumesModificationsPaginator",
     "DescribeVolumesPaginator",
