@@ -233,6 +233,7 @@ __all__ = (
     "InstanceMatchCriteriaType",
     "InstanceMetadataEndpointStateType",
     "InstanceMetadataOptionsStateType",
+    "InstanceMetadataProtocolStateType",
     "InstanceRunningWaiterName",
     "InstanceStateNameType",
     "InstanceStatusOkWaiterName",
@@ -737,6 +738,7 @@ InstanceLifecycleTypeType = Literal["scheduled", "spot"]
 InstanceMatchCriteriaType = Literal["open", "targeted"]
 InstanceMetadataEndpointStateType = Literal["disabled", "enabled"]
 InstanceMetadataOptionsStateType = Literal["applied", "pending"]
+InstanceMetadataProtocolStateType = Literal["disabled", "enabled"]
 InstanceRunningWaiterName = Literal["instance_running"]
 InstanceStateNameType = Literal[
     "pending", "running", "shutting-down", "stopped", "stopping", "terminated"
